@@ -1,15 +1,11 @@
 from typing import Union, Tuple, List
 from bs4 import BeautifulSoup
-from enum import Enum
+from enums import Urls
 import requests
 import json
 import os
 
 
-class Urls(Enum):
-    LOGIN = 'https://smarsy.ua/login.php?jsid=Login'
-
-
 def perform_get_request(session, url, params=None, headers=None):
     r = session.get(url=url, params=params, headers=headers)
     if r.status_code == 200:
@@ -18,7 +14,7 @@ def perform_get_request(session, url, params=None, headers=None):
         raise requests.HTTPError("Error code - {}".format(r.status_code))
 
 
-def perform_post_request(session, url, data=None, headers=None):
+def perform_post_request(session, url, data=None, headers=None, encoding=None):
     """
     Performs post request.
 
@@ -31,6 +27,7 @@ def perform_post_request(session, url, data=None, headers=None):
     :raises HTTPError: raises on reponse status code <> 200
     """
     r = session.post(url=url, data=data, headers=headers)
+    r.encoding = encoding
     if r.status_code == 200:
         return r.text
     else:
